@@ -1,7 +1,7 @@
 ///
 /// @file  S2Status.hpp
 ///
-/// Copyright (C) 2017 Kim Walisch, <kim.walisch@gmail.com>
+/// Copyright (C) 2018 Kim Walisch, <kim.walisch@gmail.com>
 ///
 /// This file is distributed under the BSD License. See the COPYING
 /// file in the top level directory.
@@ -11,7 +11,10 @@
 #define S2STATUS_HPP
 
 #include <int128_t.hpp>
-#include <atomic>
+
+#if defined(_OPENMP)
+  #include <OmpLock.hpp>
+#endif
 
 namespace primecount {
 
@@ -22,14 +25,18 @@ public:
   void print(maxint_t n, maxint_t limit);
   static double getPercent(int64_t low, int64_t limit, maxint_t S2, maxint_t S2_approx);
 private:
-  bool is_print(double time) const;
+  bool is_print(double time);
   void print(double percent) const;
   static double skewed_percent(maxint_t x, maxint_t y);
   double epsilon_;
-  std::atomic<double> percent_;
-  std::atomic<double> time_;
-  double is_print_;
+  double percent_ = -1;
+  double time_ = 0;
+  double is_print_ = 1.0 / 20;
   int precision_;
+
+#if defined(_OPENMP)
+  OmpLock lock_;
+#endif
 };
 
 } // namespace
