@@ -1,7 +1,7 @@
 ///
 /// @file  print.hpp
 ///
-/// Copyright (C) 2017 Kim Walisch, <kim.walisch@gmail.com>
+/// Copyright (C) 2018 Kim Walisch, <kim.walisch@gmail.com>
 ///
 /// This file is distributed under the BSD License. See the COPYING
 /// file in the top level directory.
@@ -29,13 +29,15 @@ bool print_variables();
 
 void print(const std::string& str);
 
+void print(const std::string& str, maxint_t res);
+
 void print(maxint_t x, int64_t y, int threads);
 
 void print(maxint_t x, int64_t y, int64_t c, int threads);
 
 void print(maxint_t x, int64_t y, int64_t z, int64_t c, double alpha, int threads);
 
-void print(const std::string& res_name, maxint_t res, double time);
+void print(const std::string& str, maxint_t res, double time);
 
 void print_seconds(double seconds);
 
