@@ -1,7 +1,7 @@
 ///
 /// @file  pi_lehmer.cpp
 ///
-/// Copyright (C) 2017 Kim Walisch, <kim.walisch@gmail.com>
+/// Copyright (C) 2018 Kim Walisch, <kim.walisch@gmail.com>
 ///
 /// This file is distributed under the BSD License. See the COPYING
 /// file in the top level directory.
@@ -10,11 +10,9 @@
 #include <primecount.hpp>
 #include <primecount-internal.hpp>
 #include <imath.hpp>
+#include <print.hpp>
 
 #include <stdint.h>
-#include <iostream>
-
-using namespace std;
 
 namespace primecount {
 
@@ -30,17 +28,21 @@ int64_t pi_lehmer(int64_t x, int threads)
   int64_t y = iroot<4>(x);
   int64_t a = pi_legendre(y);
 
-  if (is_print())
-  {
-    cout << endl;
-    cout << "=== pi_lehmer(x) ===" << endl;
-    cout << "pi(x) = phi(x, a) + a - 1 - P2 - P3" << endl;
-    cout << "x = " << x << endl;
-    cout << "a = " << a << endl;
-    cout << "threads = " << threads << endl;
-  }
+  print("");
+  print("=== pi_lehmer(x) ===");
+  print("pi(x) = phi(x, a) + a - 1 - P2 - P3");
+  print("x", x);
+  print("y", y);
+  print("a", a);
+  print("threads", threads);
 
+  print("");
+  print("=== phi(x, a) ===");
+  print("Count the numbers <= x coprime to the first a primes");
+  double time = get_time();
   int64_t p1 = phi(x, a, threads);
+  print("phi", p1, time);
+
   int64_t p2 = P2(x, y, threads);
   int64_t p3 = P3(x, a, threads);
   int64_t sum = p1 + a - 1 - p2 - p3;
